@@ -1,5 +1,4 @@
-/* -*-mode:c; c-style:k&r; c-basic-offset:4; -*-
- *
+/*
  * gnect gfx.h
  *
  */
@@ -10,7 +9,7 @@
 #define _GNECT_GFX_H_
 
 
-#include "gdk/gdk.h"
+#include <gdk/gdk.h>
 #include "theme.h"
 
 
